PrismBootstrapper class abstract

Constructors

PrismBootstrapper()

Properties

catalog ↔ ModuleCatalog
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
modules ↔ List<Module>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

configureContainer(Object container) → void
createContainer() → Object
createModuleCatalog() → ModuleCatalog
createModules(Object container) → void
initModules(Object container) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run() → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited